pluginmanager

package
v0.0.0-...-2cd5e1a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PluginManagerPlugin

type PluginManagerPlugin struct {
	// contains filtered or unexported fields
}

PluginManagerPlugin displays the status of registered plugins.

func New

New creates a new instance of the PluginManagerPlugin. It requires the main PluginManager to access the list of loaded plugins.

func (*PluginManagerPlugin) Execute

func (p *PluginManagerPlugin) Execute(identifier string) tea.Cmd

Execute is a no-op for this plugin.

func (*PluginManagerPlugin) GetError

func (p *PluginManagerPlugin) GetError() error

GetError returns nil as this plugin does not maintain an error state.

func (*PluginManagerPlugin) GetResults

func (p *PluginManagerPlugin) GetResults(query string) ([]plugin.Result, error)

GetResults generates a sorted list of all plugins and their status.

func (*PluginManagerPlugin) Init

func (p *PluginManagerPlugin) Init() tea.Cmd

Init initializes the plugin.

func (*PluginManagerPlugin) Keyword

func (p *PluginManagerPlugin) Keyword() string

Keyword returns the plugin's keyword.

func (*PluginManagerPlugin) Metadata

func (p *PluginManagerPlugin) Metadata() plugin.Metadata

Metadata returns the plugin's metadata.

func (*PluginManagerPlugin) Name

func (p *PluginManagerPlugin) Name() string

Name returns the plugin's name.

func (*PluginManagerPlugin) Update

func (p *PluginManagerPlugin) Update(msg tea.Msg) (plugin.Plugin, tea.Cmd)

Update is a no-op for this plugin.

func (*PluginManagerPlugin) View

func (p *PluginManagerPlugin) View() string

View returns an empty string as this plugin uses the main application's list view.

Jump to